pub enum SentinelError {
Show 16 variants
Io {
source: Error,
},
Json {
source: Error,
},
DocumentNotFound {
id: String,
collection: String,
},
CollectionNotFound {
name: String,
},
DocumentAlreadyExists {
id: String,
collection: String,
},
InvalidDocumentId {
id: String,
},
InvalidCollectionName {
name: String,
},
StoreCorruption {
reason: String,
},
TransactionFailed {
reason: String,
},
LockFailed {
reason: String,
},
CryptoFailed {
operation: String,
},
Wal {
source: WalError,
},
ConfigError {
message: String,
},
HashVerificationFailed {
id: String,
reason: String,
},
SignatureVerificationFailed {
id: String,
reason: String,
},
Internal {
message: String,
},
}Expand description
Sentinel-wide error type for the document DBMS.
This error type encompasses all possible errors that can occur within the Sentinel system, providing structured error handling and meaningful error messages for different failure scenarios.
Variants
Io
I/O operations failed (file system, network, etc.)
Json
JSON serialization/deserialization failed
DocumentNotFound
Document not found in collection
CollectionNotFound
Collection not found in store
DocumentAlreadyExists
Document already exists (for operations that require uniqueness)
InvalidDocumentId
Invalid document ID format
InvalidCollectionName
Invalid collection name format
StoreCorruption
Store is corrupted or in an invalid state
TransactionFailed
Transaction failed
LockFailed
Lock acquisition failed
CryptoFailed
Encryption/decryption operation failed
Wal
WAL (Write-Ahead Logging) operations failed
ConfigError
Configuration error
HashVerificationFailed
Document hash verification failed
SignatureVerificationFailed
Document signature verification failed
Internal
Generic error for unexpected conditions